==> aws-java-sdk-1.7.1-sources.jar: com/amazonaws/services/sqs/model/ListDeadLetterSourceQueuesRequest.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.sqs.model;

import java.io.Serializable;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * Container for the parameters to the {@link com.amazonaws.services.sqs.AmazonSQS#listDeadLetterSourceQueues(ListDeadLetterSourceQueuesRequest) ListDeadLetterSourceQueues operation}.
 * <p>
 * Returns a list of your queues that have the RedrivePolicy queue attribute configured with a dead letter queue.
 * </p>
 *
 * @see com.amazonaws.services.sqs.AmazonSQS#listDeadLetterSourceQueues(ListDeadLetterSourceQueuesRequest)
 */
public class ListDeadLetterSourceQueuesRequest extends AmazonWebServiceRequest implements Serializable {

    /**
     * The queue URL of a dead letter queue.
     */
    private String queueUrl;

    /**
     * The queue URL of a dead letter queue.
     *
     * @return The queue URL of a dead letter queue.
     */
    public String getQueueUrl() {
        return queueUrl;
    }
    
    /**
     * The queue URL of a dead letter queue.
     *
     * @param queueUrl The queue URL of a dead letter queue.
     */
    public void setQueueUrl(String queueUrl) {
        this.queueUrl = queueUrl;
    }
    
    /**
     * The queue URL of a dead letter queue.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param queueUrl The queue URL of a dead letter queue.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together.
     */
    public ListDeadLetterSourceQueuesRequest withQueueUrl(String queueUrl) {
        this.queueUrl = queueUrl;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getQueueUrl() != null) sb.append("QueueUrl: " + getQueueUrl() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getQueueUrl() == null) ? 0 : getQueueUrl().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof ListDeadLetterSourceQueuesRequest == false) return false;
        ListDeadLetterSourceQueuesRequest other = (ListDeadLetterSourceQueuesRequest)obj;
        
        if (other.getQueueUrl() == null ^ this.getQueueUrl() == null) return false;
        if (other.getQueueUrl() != null && other.getQueueUrl().equals(this.getQueueUrl()) == false) return false; 
        return true;
    }
    
}

==> aws-java-sdk-1.7.3-sources.jar: com/amazonaws/services/sqs/model/ListDeadLetterSourceQueuesRequest.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.sqs.model;

import java.io.Serializable;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * Container for the parameters to the {@link com.amazonaws.services.sqs.AmazonSQS#listDeadLetterSourceQueues(ListDeadLetterSourceQueuesRequest) ListDeadLetterSourceQueues operation}.
 * <p>
 * Returns a list of your queues that have the RedrivePolicy queue
 * attribute configured with a dead letter queue.
 * </p>
 *
 * @see com.amazonaws.services.sqs.AmazonSQS#listDeadLetterSourceQueues(ListDeadLetterSourceQueuesRequest)
 */
public class ListDeadLetterSourceQueuesRequest extends AmazonWebServiceRequest implements Serializable {

    /**
     * The queue URL of a dead letter queue.
     */
    private String queueUrl;

    /**
     * The queue URL of a dead letter queue.
     *
     * @return The queue URL of a dead letter queue.
     */
    public String getQueueUrl() {
        return queueUrl;
    }
    
    /**
     * The queue URL of a dead letter queue.
     *
     * @param queueUrl The queue URL of a dead letter queue.
     */
    public void setQueueUrl(String queueUrl) {
        this.queueUrl = queueUrl;
    }
    
    /**
     * The queue URL of a dead letter queue.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param queueUrl The queue URL of a dead letter queue.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together.
     */
    public ListDeadLetterSourceQueuesRequest withQueueUrl(String queueUrl) {
        this.queueUrl = queueUrl;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getQueueUrl() != null) sb.append("QueueUrl: " + getQueueUrl() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getQueueUrl() == null) ? 0 : getQueueUrl().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof ListDeadLetterSourceQueuesRequest == false) return false;
        ListDeadLetterSourceQueuesRequest other = (ListDeadLetterSourceQueuesRequest)obj;
        
        if (other.getQueueUrl() == null ^ this.getQueueUrl() == null) return false;
        if (other.getQueueUrl() != null && other.getQueueUrl().equals(this.getQueueUrl()) == false) return false; 
        return true;
    }
    
}
